@@ -8,7 +8,7 @@ import itertools
 import locale
 import logging
 import math
-from PyQt5.QtCore import (QObject, QTimer, Qt)
+from PyQt5.QtCore import QObject, QTimer, Qt
 import re
 import struct
 import sys
@@ -19,8 +19,8 @@ import epyqlib.utils.qt
 import epyqlib.utils.units
 
 # See file COPYING in this source tree
-__copyright__ = 'Copyright 2016, EPC Power Corp.'
-__license__ = 'GPLv2+'
+__copyright__ = "Copyright 2016, EPC Power Corp."
+__license__ = "GPLv2+"
 
 
 class OutOfRangeError(ValueError):
@@ -39,14 +39,14 @@ nothing = object()
 
 
 def strip_uuid_from_comment(comment):
-    match = re.search(r'<uuid:([a-z0-9-]+)>', comment)
+    match = re.search(r"<uuid:([a-z0-9-]+)>", comment)
 
     if match is None:
         return comment, None
 
     uuid_object = uuid.UUID(match[1])
 
-    stripped_comment = comment.replace(match[0], '').strip()
+    stripped_comment = comment.replace(match[0], "").strip()
 
     return stripped_comment, uuid_object
 
@@ -58,7 +58,7 @@ class ReadWrite:
 
 
 def strip_rw_from_comment(comment):
-    match = re.search(r'<rw:([01]):([01])>', comment)
+    match = re.search(r"<rw:([01]):([01])>", comment)
 
     if match is None:
         return comment, None
@@ -68,7 +68,7 @@ def strip_rw_from_comment(comment):
         writable=bool(int(match[2])),
     )
 
-    stripped_comment = comment.replace(match[0], '').strip()
+    stripped_comment = comment.replace(match[0], "").strip()
 
     return stripped_comment, rw
 
@@ -77,27 +77,23 @@ def strip_rw_from_comment(comment):
 def pack_bitstring(length, is_float, value, signed):
     if is_float:
         # TODO: CAMPid 097897541967932453154321546542175421549
-        types = {
-            32: '>f',
-            64: '>d'
-        }
+        types = {32: ">f", 64: ">d"}
 
         float_type = types.get(length)
 
         if float_type is None:
             raise Exception(
-                'float type only supports lengths in [{}]'.
-                    format(', '.join([str(t) for t in types.keys()]))
+                "float type only supports lengths in [{}]".format(
+                    ", ".join([str(t) for t in types.keys()])
+                )
             )
 
-        x, = struct.pack(float_type, value)
+        (x,) = struct.pack(float_type, value)
 
-        bitstring = ''.join('{:08b}'.format(b) for b in x)
+        bitstring = "".join("{:08b}".format(b) for b in x)
     else:
-        b = value.to_bytes(math.ceil(length/8), byteorder='big',
-                             signed=signed)
-        b = '{:0{}b}'.format(int.from_bytes(b, byteorder='big'),
-                             length)
+        b = value.to_bytes(math.ceil(length / 8), byteorder="big", signed=signed)
+        b = "{:0{}b}".format(int.from_bytes(b, byteorder="big"), length)
         bitstring = b[:length]
 
     return bitstring
@@ -107,38 +103,35 @@ def pack_bitstring(length, is_float, value, signed):
 def unpack_bitstring(length, is_float, is_signed, bits):
     if is_float:
         # TODO: CAMPid 097897541967932453154321546542175421549
-        types = {
-            32: '>f',
-            64: '>d'
-        }
+        types = {32: ">f", 64: ">d"}
 
         float_type = types.get(length)
 
         if float_type is None:
             raise Exception(
-                'float type only supports lengths in [{}]'.
-                    format(', '.join([str(t) for t in types.keys()]))
+                "float type only supports lengths in [{}]".format(
+                    ", ".join([str(t) for t in types.keys()])
+                )
             )
 
-        value, = struct.unpack(
+        (value,) = struct.unpack(
             float_type,
-            bytes(int(''.join(b), 2)
-                      for b in epyqlib.utils.general.grouper(bits, 8))
+            bytes(int("".join(b), 2) for b in epyqlib.utils.general.grouper(bits, 8)),
         )
     else:
         value = int(bits, 2)
 
-        if is_signed and bits[0] == '1':
-            value -= (1 << len(bits))
+        if is_signed and bits[0] == "1":
+            value -= 1 << len(bits)
 
     return value
 
 
 @functools.lru_cache(4096)
 def bytes_to_bitstrings(data):
-    b = tuple('{:08b}'.format(b) for b in data)
-    little = ''.join(reversed(b))
-    big = ''.join(b)
+    b = tuple("{:08b}".format(b) for b in data)
+    little = "".join(reversed(b))
+    big = "".join(b)
 
     return little, big
 
@@ -179,17 +172,15 @@ def signals_to_bytes(length, signals, data):
             least = most + signal.signal_size
 
             big_bits[most:least] = bits
-    little_bits = reversed(tuple(epyqlib.utils.general.grouper(
-        little_bits, 8)))
+    little_bits = reversed(tuple(epyqlib.utils.general.grouper(little_bits, 8)))
     little_bits = tuple(itertools.chain(*little_bits))
-    bitstring = ''.join(
-        next(x for x in (l, b, '0') if x is not None)
+    bitstring = "".join(
+        next(x for x in (l, b, "0") if x is not None)
         # l if l != ' ' else (b if b != ' ' else '0')
         for l, b in zip(little_bits, big_bits)
     )
     return bytes(
-        int(''.join(b), 2)
-        for b in epyqlib.utils.general.grouper(bitstring, 8)
+        int("".join(b), 2) for b in epyqlib.utils.general.grouper(bitstring, 8)
     )
 
 
@@ -201,16 +192,17 @@ class Signal:
     def __init__(self, signal, frame, connect=None, parent=None):
         # self.attributes = signal._attributes # {dict} {'GenSigStartValue': '0.0', 'LongName': 'Enable'}
         self.default_value = signal.initial_value
-        self.long_name = signal.attributes.get('LongName', None)
-        self.hexadecimal_output = signal.attributes.get('HexadecimalOutput',
-                                                         None)
+        self.long_name = signal.attributes.get("LongName", None)
+        self.hexadecimal_output = signal.attributes.get("HexadecimalOutput", None)
         self.hexadecimal_output = self.hexadecimal_output is not None
-        self.little_endian = signal.is_little_endian # {int} 0
-        self.comment = signal.comment # {str} 'Run command.  When set to a value of \\'Enable\\', causes transition to grid forming or grid following mode depending on whether AC power is detected.  Must be set to \\'Disable\\' to leave POR or FAULTED state.'
+        self.little_endian = signal.is_little_endian  # {int} 0
+        self.comment = (
+            signal.comment
+        )  # {str} 'Run command.  When set to a value of \\'Enable\\', causes transition to grid forming or grid following mode depending on whether AC power is detected.  Must be set to \\'Disable\\' to leave POR or FAULTED state.'
         if self.comment is None:
-            self.comment = ''
+            self.comment = ""
         # TODO: CAMPid 03549854754276996754265427 (repeated <summary> check)
-        self.is_summary = '<summary>' in self.comment
+        self.is_summary = "<summary>" in self.comment
         # TODO: maybe not use a string, but used to help with decimal places
         self.factor = signal.factor
         try:
@@ -228,19 +220,21 @@ class Signal:
         except ValueError:
             self.offset = 0
 
-        if signal.multiplex == 'Multiplexor':
+        if signal.multiplex == "Multiplexor":
             self.multiplex = True
         else:
-            self.multiplex = signal.multiplex # {NoneType} None
+            self.multiplex = signal.multiplex  # {NoneType} None
 
         self.raw_minimum, self.raw_maximum = signal.calculate_raw_range()
 
-        self.name = signal.name # {str} 'Enable_command'
+        self.name = signal.name  # {str} 'Enable_command'
         # self.receiver = signal.receiver # {str} ''
-        self.signal_size = int(signal.size) # {int} 2
-        self.start_bit = int(signal.get_startbit()) # {int} 0
-        self.unit = signal.unit # {str} ''
-        self.enumeration = {int(k): v for k, v in signal.values.items()} # {dict} {'0': 'Disable', '2': 'Error', '1': 'Enable', '3': 'N/A'}
+        self.signal_size = int(signal.size)  # {int} 2
+        self.start_bit = int(signal.get_startbit())  # {int} 0
+        self.unit = signal.unit  # {str} ''
+        self.enumeration = {
+            int(k): v for k, v in signal.values.items()
+        }  # {dict} {'0': 'Disable', '2': 'Error', '1': 'Enable', '3': 'N/A'}
         self.enumeration_name = signal.enumeration
         self.signed = signal.is_signed
         if self.multiplex is True:
@@ -257,20 +251,24 @@ class Signal:
             # TODO: put this into the frame!
             self.frame.signals.append(self)
 
-        self.enumeration_format_re = {'re': r'^\[(\d+)\]',
-                                      'format': '[{v}] {s}',
-                                      'no_value_format': '{s}'}
+        self.enumeration_format_re = {
+            "re": r"^\[(\d+)\]",
+            "format": "[{v}] {s}",
+            "no_value_format": "{s}",
+        }
 
         # TODO: make this configurable in the .sym?
-        self.secret = self.name.casefold() in {'factoryaccess', 'password'}
+        self.secret = self.name.casefold() in {"factoryaccess", "password"}
 
         self.decimal_places = None
 
         self._format = None
 
-        self.full_string, self.short_string, self.enumeration_text = (
-            self.format_strings(value=self.value)
-        )
+        (
+            self.full_string,
+            self.short_string,
+            self.enumeration_text,
+        ) = self.format_strings(value=self.value)
         if connect is not None:
             self.connect(connect)
 
@@ -286,11 +284,11 @@ class Signal:
             )
 
     def __str__(self):
-        return '{name}: sb:{start_bit}, osb:{ordering_start_bit}, len:{length}'.format(
+        return "{name}: sb:{start_bit}, osb:{ordering_start_bit}, len:{length}".format(
             name=self.name,
             start_bit=self.start_bit,
-            ordering_start_bit=getattr(self, 'ordering_start_bit', '-'),
-            length=self.signal_size
+            ordering_start_bit=getattr(self, "ordering_start_bit", "-"),
+            length=self.signal_size,
         )
 
     def last_received(self):
@@ -316,7 +314,7 @@ class Signal:
 
     def calc_human_value(self, raw_value):
         # TODO: handle offset
-        locale.setlocale(locale.LC_ALL, '')
+        locale.setlocale(locale.LC_ALL, "")
 
         if isinstance(raw_value, str):
             enumeration_strings = self.enumeration_strings()
@@ -324,8 +322,7 @@ class Signal:
                 try:
                     index = enumeration_strings.index(raw_value)
                 except ValueError:
-                    enumeration_strings = self.enumeration_strings(
-                        include_values=True)
+                    enumeration_strings = self.enumeration_strings(include_values=True)
                     if len(enumeration_strings) > 0:
                         try:
                             index = enumeration_strings.index(raw_value)
@@ -352,26 +349,29 @@ class Signal:
         )
 
     def set_human_value(self, raw_value, force=False, check_range=False):
-            value = self.calc_human_value(raw_value)
+        value = self.calc_human_value(raw_value)
 
-            self.set_value(
-                value=value,
-                force=force,
-                check_range=check_range,
-            )
+        self.set_value(
+            value=value,
+            force=force,
+            check_range=check_range,
+        )
 
     def enumeration_string(self, value, include_value=False):
-        format = (self.enumeration_format_re['format']
-                  if include_value
-                  else self.enumeration_format_re['no_value_format'])
+        format = (
+            self.enumeration_format_re["format"]
+            if include_value
+            else self.enumeration_format_re["no_value_format"]
+        )
 
         return format.format(v=value, s=self.enumeration[value])
 
     def enumeration_strings(self, include_values=False):
         items = list(self.enumeration)
         items.sort()
-        items = [self.enumeration_string(i, include_value=include_values)
-                 for i in items]
+        items = [
+            self.enumeration_string(i, include_value=include_values) for i in items
+        ]
 
         return items
 
@@ -392,7 +392,9 @@ class Signal:
                     return (magnitude, 0)
                 frac_part = abs(x) - int_part
                 multiplier = 10 ** (max_digits - magnitude)
-                frac_digits = multiplier + int(multiplier * frac_part + decimal.Decimal('0.5'))
+                frac_digits = multiplier + int(
+                    multiplier * frac_part + decimal.Decimal("0.5")
+                )
                 while frac_digits % 10 == 0:
                     frac_digits /= 10
                 scale = int(math.log10(frac_digits))
@@ -414,14 +416,17 @@ class Signal:
         if check_range:
             human_value = self.to_human(value)
             if not minimum <= human_value <= maximum:
-                raise OutOfRangeError('{} not in range [{}, {}]'.format(
-                    *[self.format_float(f) for f
-                      in (human_value, minimum, maximum)]))
+                raise OutOfRangeError(
+                    "{} not in range [{}, {}]".format(
+                        *[self.format_float(f) for f in (human_value, minimum, maximum)]
+                    )
+                )
 
         return True
 
-    def set_value(self, value, force=False, check_range=False, minimum=None,
-                  maximum=None):
+    def set_value(
+        self, value, force=False, check_range=False, minimum=None, maximum=None
+    ):
         ok = Signal.check_value(
             self=self,
             value=value,
@@ -445,18 +450,18 @@ class Signal:
                     # TODO: CAMPid 9395616283654658598648263423685
                     # TODO: and _offset...
 
-                    self.scaled_value = (
-                        self.offset + (self.value * self.factor)
-                    )
+                    self.scaled_value = self.offset + (self.value * self.factor)
 
                     value = self.scaled_value
 
-            self.full_string, self.short_string, self.enumeration_text = (
-                self.format_strings(value=value_parameter)
-            )
+            (
+                self.full_string,
+                self.short_string,
+                self.enumeration_text,
+            ) = self.format_strings(value=value_parameter)
 
             if value_parameter is None:
-                self.value_changed.emit(float('nan'))
+                self.value_changed.emit(float("nan"))
             else:
                 self.value_changed.emit(value)
 
@@ -465,8 +470,8 @@ class Signal:
 
     def format_strings(self, value):
         if value is None or (type(value) is float and math.isnan(value)):
-            full_string = '-'
-            short_string = '-'
+            full_string = "-"
+            short_string = "-"
             enumeration_text = None
         else:
             enumeration_text = None
@@ -474,30 +479,31 @@ class Signal:
             try:
                 # TODO: CAMPid 94562754956589992752348667
                 enum_string = self.enumeration[value]
-                full_string = self.enumeration_format_re['format'].format(
-                        s=enum_string, v=value)
+                full_string = self.enumeration_format_re["format"].format(
+                    s=enum_string, v=value
+                )
                 enumeration_text = enum_string
                 short_string = enum_string
             except KeyError:
                 # TODO: this should be a subclass or something
                 if self.hexadecimal_output:
-                    format = '{{:0{}X}}'.format(math.ceil(self.signal_size/math.log2(16)))
+                    format = "{{:0{}X}}".format(
+                        math.ceil(self.signal_size / math.log2(16))
+                    )
                     full_string = format.format(int(value))
                     short_string = full_string
                 else:
                     # TODO: CAMPid 9395616283654658598648263423685
                     # TODO: and _offset...
 
-                    scaled_value = (
-                        self.offset + (value * self.factor)
-                    )
+                    scaled_value = self.offset + (value * self.factor)
 
                     full_string = self.format_float(scaled_value)
                     short_string = full_string
 
                     if self.unit is not None:
                         if len(self.unit) > 0:
-                            full_string += ' [{}]'.format(self.unit)
+                            full_string += " [{}]".format(self.unit)
 
         return full_string, short_string, enumeration_text
 
@@ -509,23 +515,23 @@ class Signal:
 
     def format_float(self, value=None, decimal_places=None, for_file=False):
         if self.secret:
-            return '<secret>'
+            return "<secret>"
 
         # TODO: ack fix this since it's getting called with an actual None value...
         if value is None:
             value = self.scaled_value
 
         if value is None:
-            formatted = '-'
+            formatted = "-"
         else:
             if decimal_places is None:
                 decimal_places = self.get_decimal_places()
 
             if for_file:
-                format = '{{:.{}f}}'.format(self.get_decimal_places())
+                format = "{{:.{}f}}".format(self.get_decimal_places())
                 formatted = format.format(value)
             else:
-                format = '%.{}f'.format(decimal_places)
+                format = "%.{}f".format(decimal_places)
                 formatted = locale_format(format, value)
 
         return formatted
@@ -540,10 +546,10 @@ class Signal:
             return pack_bitstring(self.signal_size, self.float, value, self.signed)
         except OverflowError as e:
             names = (self.frame.name, self.frame.mux_name, self.name)
-            name = ':'.join(name for name in names if name is not None)
+            name = ":".join(name for name in names if name is not None)
             raise UnableToPackError(
-                'Unable to pack {value} into {name} with range '
-                '[{minimum}, {maximum}]'.format(
+                "Unable to pack {value} into {name} with range "
+                "[{minimum}, {maximum}]".format(
                     value=value,
                     name=name,
                     minimum=self.raw_minimum,
@@ -555,7 +561,7 @@ class Signal:
         return unpack_bitstring(self.signal_size, self.float, self.signed, bits)
 
     def some_packable_value(self):
-        return self.unpack_bitstring(bits='0' * self.signal_size)
+        return self.unpack_bitstring(bits="0" * self.signal_size)
 
 
 @functools.lru_cache(10000)
@@ -593,29 +599,38 @@ class QtCanListener(can.Listener):
 
 
 class Frame(QtCanListener):
-    send = epyqlib.utils.qt.Signal(can.Message, 'PyQt_PyObject')
+    send = epyqlib.utils.qt.Signal(can.Message, "PyQt_PyObject")
 
-    def __init__(self, frame, multiplex_value=None,
-                 signal_class=Signal, set_value_to_default=True,
-                 mux_frame=None, strip_summary=True, parent=None):
+    def __init__(
+        self,
+        frame,
+        multiplex_value=None,
+        signal_class=Signal,
+        set_value_to_default=True,
+        mux_frame=None,
+        strip_summary=True,
+        parent=None,
+    ):
         super().__init__(self.message_received, parent=parent)
 
         self.mux_frame = mux_frame
 
-        self.id = frame.arbitration_id.id # {int} 16755521
+        self.id = frame.arbitration_id.id  # {int} 16755521
         # self.SignalGroups = frame.SignalGroups # {list} []
-        self.size = frame.size # {int} 8
+        self.size = frame.size  # {int} 8
         # self.Transmitter = frame.Transmitter # {list} []
         # self.attributes = frame.attributes # {dict} {'GenMsgCycleTime': '200'}
         self.cycle_time = frame.cycle_time if frame.cycle_time != 0 else None
-        self.mux_name = frame.attributes.get('mux_name', None)
-        self.sendable = frame.attributes.get('Sendable') == 'True'
-        self.receivable = frame.attributes.get('Receivable') == 'True'
-        self.comment = frame.comment # {str} 'Operational commands are received by the module via control bits within this message.'
+        self.mux_name = frame.attributes.get("mux_name", None)
+        self.sendable = frame.attributes.get("Sendable") == "True"
+        self.receivable = frame.attributes.get("Receivable") == "True"
+        self.comment = (
+            frame.comment
+        )  # {str} 'Operational commands are received by the module via control bits within this message.'
         if self.comment is None:
-            self.comment = ''
-        self.extended = bool(frame.arbitration_id.extended) # {int} 1
-        self.name = frame.name # {str} 'CommandModeControl'
+            self.comment = ""
+        self.extended = bool(frame.arbitration_id.extended)  # {int} 1
+        self.name = frame.name  # {str} 'CommandModeControl'
         # self.receiver = frame.receiver # {list} []
         # self.signals = frame.signals # {list} [<canmatrix.canmatrix.Signal object at 0x7fddf8053fd0>, <canmatrix.canmatrix.Signal object at 0x7fddf8054048>, <canmatrix.canmatrix.Signal object at 0x7fddf80543c8>, <canmatrix.canmatrix.Signal object at 0x7fddf8054470>, <canmatrix.canmatrix.Signal object
 
@@ -636,13 +651,12 @@ class Frame(QtCanListener):
             skipping_summary_signal = (
                 strip_summary
                 and signal.comment is not None
-                and '<summary>' in signal.comment
+                and "<summary>" in signal.comment
             )
             if skipping_summary_signal:
                 continue
 
-            if (multiplex_value is None or
-                        str(signal.multiplex) == multiplex_value):
+            if multiplex_value is None or str(signal.multiplex) == multiplex_value:
                 neo_signal = signal_class(signal=signal, frame=self)
 
                 factor = neo_signal.factor
@@ -651,15 +665,14 @@ class Frame(QtCanListener):
 
                 offset = neo_signal.offset
                 if offset is None:
-                    offset = decimal.Decimal('0')
+                    offset = decimal.Decimal("0")
 
                 default_value = neo_signal.default_value
                 if default_value is None:
                     default_value = 0
 
                 if set_value_to_default:
-                    neo_signal.set_human_value(
-                        offset + (default_value * factor))
+                    neo_signal.set_human_value(offset + (default_value * factor))
 
         self.signals = tuple(self.signals)
 
@@ -714,7 +727,11 @@ class Frame(QtCanListener):
     def unpack(self, data, report_error=True, only_return=False):
         rx_length = len(data)
         if rx_length != self.size and report_error:
-            print('Received message 0x{self.id:08X} with length {rx_length}, expected {self.size}'.format(**locals()))
+            print(
+                "Received message 0x{self.id:08X} with length {rx_length}, expected {self.size}".format(
+                    **locals()
+                )
+            )
         else:
             little, big = bytes_to_bitstrings(bytes(data))
 
@@ -763,8 +780,7 @@ class Frame(QtCanListener):
             if self._cyclic_period is None:
                 self.timer.stop()
             else:
-                self.timer.setInterval(
-                    int(round(float(self._cyclic_period) * 1000)))
+                self.timer.setInterval(int(round(float(self._cyclic_period) * 1000)))
                 if not self.timer.isActive():
                     self.timer.start()
 
@@ -772,16 +788,14 @@ class Frame(QtCanListener):
         if data is None:
             data = self.data
 
-        return can.Message(extended_id=self.extended,
-                           arbitration_id=self.id,
-                           dlc=self.size,
-                           data=data)
+        return can.Message(
+            extended_id=self.extended, arbitration_id=self.id, dlc=self.size, data=data
+        )
 
     def message_received(self, msg):
         unpacked = False
 
-        if (msg.arbitration_id == self.id and
-                bool(msg.is_extended_id) == self.extended):
+        if msg.arbitration_id == self.id and bool(msg.is_extended_id) == self.extended:
             if self.mux_frame is None:
                 self.unpack(msg.data)
                 unpacked = True
@@ -789,13 +803,12 @@ class Frame(QtCanListener):
                 # print(self, self.name, self.mux_name, self.mux_frame, self.mux_frame.name, self.mux_frame.mux_name)
 
                 unpacked = self.mux_frame.unpack(msg.data, only_return=True)
-                mux_signal, = unpacked
+                (mux_signal,) = unpacked
 
                 # TODO: this if added to avoid exceptions temporarily
                 if mux_signal.value in self.multiplex_frames:
-                    unpacked = (
-                        self.multiplex_frames[mux_signal.value]
-                            .message_received(msg)
+                    unpacked = self.multiplex_frames[mux_signal.value].message_received(
+                        msg
                     )
             else:
                 self.unpack(msg.data)
@@ -811,18 +824,15 @@ class Frame(QtCanListener):
         for caller in callers:
             self.cyclic_request(caller, None)
 
-        logging.debug('{} terminated'.format(object.__repr__(self)))
+        logging.debug("{} terminated".format(object.__repr__(self)))
 
 
 @functools.lru_cache(1024)
 def frame_by_id(id, frames):
-    found = (
-        f for f in frames
-        if f.id == id and f.mux_name is None
-    )
+    found = (f for f in frames if f.id == id and f.mux_name is None)
 
     try:
-        frame, = found
+        (frame,) = found
     except ValueError:
         return None
 
@@ -830,9 +840,17 @@ def frame_by_id(id, frames):
 
 
 class Neo(QtCanListener):
-    def __init__(self, matrix, frame_class=Frame, signal_class=Signal,
-                 rx_interval=0, bus=None, node_id_adjust=None,
-                 strip_summary=True, parent=None):
+    def __init__(
+        self,
+        matrix,
+        frame_class=Frame,
+        signal_class=Signal,
+        rx_interval=0,
+        bus=None,
+        node_id_adjust=None,
+        strip_summary=True,
+        parent=None,
+    ):
         super().__init__(self.message_received, parent=parent)
 
         self.bus = None
@@ -848,14 +866,14 @@ class Neo(QtCanListener):
                     id=node_id_adjust(
                         message_id=frame.arbitration_id.id,
                         to_device=(
-                            frame.attributes['Receivable'].casefold() == 'false'
+                            frame.attributes["Receivable"].casefold() == "false"
                         ),
                     ),
                     extended=frame.arbitration_id.extended,
                 )
             multiplex_signal = None
             for signal in frame.signals:
-                if signal.multiplex == 'Multiplexor':
+                if signal.multiplex == "Multiplexor":
                     multiplex_signal = signal
                     break
 
@@ -880,17 +898,18 @@ class Neo(QtCanListener):
                     cycle_time=frame.cycle_time,
                 )
                 matrix_signal = canmatrix.Signal(
-                        name=multiplex_signal.name,
-                        start_bit=multiplex_signal.start_bit,
-                        size=multiplex_signal.size,
-                        is_little_endian=multiplex_signal.is_little_endian,
-                        is_signed=multiplex_signal.is_signed,
-                        factor=multiplex_signal.factor,
-                        offset=multiplex_signal.offset,
-                        min=multiplex_signal.min,
-                        max=multiplex_signal.max,
-                        unit=multiplex_signal.unit,
-                        multiplex=multiplex_signal.multiplex)
+                    name=multiplex_signal.name,
+                    start_bit=multiplex_signal.start_bit,
+                    size=multiplex_signal.size,
+                    is_little_endian=multiplex_signal.is_little_endian,
+                    is_signed=multiplex_signal.is_signed,
+                    factor=multiplex_signal.factor,
+                    offset=multiplex_signal.offset,
+                    min=multiplex_signal.min,
+                    max=multiplex_signal.max,
+                    unit=multiplex_signal.unit,
+                    multiplex=multiplex_signal.multiplex,
+                )
                 multiplex_frame.add_signal(matrix_signal)
                 multiplex_neo_frame = frame_class(
                     frame=multiplex_frame,
@@ -899,8 +918,7 @@ class Neo(QtCanListener):
                 multiplex_neo_frame.mux_frame = multiplex_neo_frame
                 frames.append(multiplex_neo_frame)
 
-                multiplex_neo_frame.multiplex_signal =\
-                    multiplex_neo_frame.signals[0]
+                multiplex_neo_frame.multiplex_signal = multiplex_neo_frame.signals[0]
 
                 multiplex_neo_frame.multiplex_frames = {}
 
@@ -914,21 +932,23 @@ class Neo(QtCanListener):
                         transmitters=list(frame.transmitters),
                         cycle_time=frame.cycle_time,
                     )
-                    matrix_frame.add_attribute('mux_name', multiplex_name)
-                    matrix_frame.add_comment(multiplex_signal.comments[int(
-                        multiplex_value)])
+                    matrix_frame.add_attribute("mux_name", multiplex_name)
+                    matrix_frame.add_comment(
+                        multiplex_signal.comments[int(multiplex_value)]
+                    )
                     matrix_signal = canmatrix.Signal(
-                            name=multiplex_signal.name,
-                            start_bit=multiplex_signal.start_bit,
-                            size=multiplex_signal.size,
-                            is_little_endian=multiplex_signal.is_little_endian,
-                            is_signed=multiplex_signal.is_signed,
-                            factor=multiplex_signal.factor,
-                            offset=multiplex_signal.offset,
-                            min=multiplex_signal.min,
-                            max=multiplex_signal.max,
-                            unit=multiplex_signal.unit,
-                            multiplex=multiplex_signal.multiplex)
+                        name=multiplex_signal.name,
+                        start_bit=multiplex_signal.start_bit,
+                        size=multiplex_signal.size,
+                        is_little_endian=multiplex_signal.is_little_endian,
+                        is_signed=multiplex_signal.is_signed,
+                        factor=multiplex_signal.factor,
+                        offset=multiplex_signal.offset,
+                        min=multiplex_signal.min,
+                        max=multiplex_signal.max,
+                        unit=multiplex_signal.unit,
+                        multiplex=multiplex_signal.multiplex,
+                    )
                     # neo_signal = signal_class(signal=matrix_signal, frame=multiplex_neo_frame)
                     matrix_frame.add_signal(matrix_signal)
 
@@ -945,8 +965,7 @@ class Neo(QtCanListener):
                         if signal.multiplex is True:
                             signal.set_value(multiplex_value)
                     frames.append(neo_frame)
-                    multiplex_neo_frame.\
-                        multiplex_frames[multiplex_value] = neo_frame
+                    multiplex_neo_frame.multiplex_frames[multiplex_value] = neo_frame
 
         self.frames = tuple(frames)
 
@@ -962,7 +981,7 @@ class Neo(QtCanListener):
 
     def set_bus(self, bus):
         if self.bus is not None:
-            raise Exception('Bus already set')
+            raise Exception("Bus already set")
 
         self.bus = bus
 
@@ -994,12 +1013,11 @@ class Neo(QtCanListener):
         if frame is None:
             raise NotFoundError(repr(elements))
 
-        if hasattr(frame, 'multiplex_frames'):
+        if hasattr(frame, "multiplex_frames"):
             element = get_next(i)
 
             frames = (
-                f for f in frame.multiplex_frames.values()
-                if f.mux_name == element
+                f for f in frame.multiplex_frames.values() if f.mux_name == element
             )
             try:
                 [frame] = frames
@@ -1017,7 +1035,7 @@ class Neo(QtCanListener):
     def get_multiplex(self, message):
         base_frame = self.frame_by_id(message.arbitration_id)
 
-        if not hasattr(base_frame, 'multiplex_frames'):
+        if not hasattr(base_frame, "multiplex_frames"):
             frame = base_frame
             multiplex_value = None
         else:
@@ -1034,8 +1052,7 @@ class Neo(QtCanListener):
     def message_received(self, msg):
         frame = self.frame_by_id(msg.arbitration_id)
         if frame is not None:
-            last = self.frame_rx_timestamps.get(frame,
-                                                -self.frame_rx_interval)
+            last = self.frame_rx_timestamps.get(frame, -self.frame_rx_interval)
             if msg.timestamp - last >= self.frame_rx_interval:
                 self.frame_rx_timestamps[frame] = msg.timestamp
                 frame.message_received_signal.emit(msg)
@@ -1053,16 +1070,18 @@ class Neo(QtCanListener):
         )
 
         for f in cached_functions:
-            logging.debug('epyqlib.canneo.{}(): {}'.format(
-                f.__name__,
-                f.cache_info(),
-            ))
-        logging.debug('{} terminated'.format(object.__repr__(self)))
+            logging.debug(
+                "epyqlib.canneo.{}(): {}".format(
+                    f.__name__,
+                    f.cache_info(),
+                )
+            )
+        logging.debug("{} terminated".format(object.__repr__(self)))
 
 
 @functools.lru_cache(128)
 def format_identifier(identifier, extended):
-    f = '0x{{:0{}X}}'
+    f = "0x{{:0{}X}}"
 
     if extended:
         f = f.format(8)
@@ -1071,6 +1090,7 @@ def format_identifier(identifier, extended):
 
     return f.format(identifier)
 
+
 @functools.lru_cache(1024)
 def format_data(data):
-    return ' '.join(['{:02X}'.format(byte) for byte in data])
+    return " ".join(["{:02X}".format(byte) for byte in data])
