@@ -2,18 +2,18 @@ import epyqlib.form
 import epyqlib.abstractpluginclass
 
 # See file COPYING in this source tree
-__copyright__ = 'Copyright 2016, EPC Power Corp.'
-__license__ = 'GPLv2+'
+__copyright__ = "Copyright 2016, EPC Power Corp."
+__license__ = "GPLv2+"
 
 
 class FormPlugin(epyqlib.abstractpluginclass.AbstractPlugin):
     def __init__(self, parent=None):
         epyqlib.abstractpluginclass.AbstractPlugin.__init__(self, parent=parent)
 
-        self._group = 'EPC - General'
+        self._group = "EPC - General"
         self._init = epyqlib.form.EpcForm
-        self._module_path = 'epyqlib.form'
-        self._name = 'EpcForm'
+        self._module_path = "epyqlib.form"
+        self._name = "EpcForm"
 
     def isContainer(self):
         return True
